@@ -236,7 +236,7 @@ class BERT(Transformer):
             return [x_in,s_in,p_in]
         return [x_in,s_in]
     
-    def apply_embedding(self,inputs):
+    def apply_embeddings(self,inputs):
         x,s = inputs[:2]
         z = self.layer_norm_conds[0]
         if self.custom_position_ids:
@@ -615,23 +615,13 @@ def build_transformer_model(
     model, application = model.lower(), application.lower()
 
     models = {
-        'bert': BERT,
-        'albert': ALBERT,
-        'albert_unshared': ALBERT_Unshared,
-        'nezha': NEZHA,
-        'electra': ELECTRA,
-        'gpt2_ml': GPT2_ML,
-        't5': T5,
+        'bert': BERT
     }
     MODEL = models[model]
 
     if model != 't5':
         if application == 'lm':
             MODEL = extend_with_language_model(MODEL)
-        elif application == 'unilm':
-            MODEL = extend_with_unified_language_model(MODEL)
-        elif application == 'punilm':
-            MODEL = extend_with_parallel_unified_language_model(MODEL)
 
     transformer = MODEL(**configs)
     transformer.build(**configs)
